@@ -1,10 +1,10 @@
       SUBROUTINE PCGEQPF( M, N, A, IA, JA, DESCA, IPIV, TAU, WORK,
-     $                    LWORK, RWORK, LRWORK, INFO )
+     $                     LWORK, RWORK, LRWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.7) --
+*  -- ScaLAPACK routine (version 2.1) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     March 14, 2000
+*     November 20, 2019
 *
 *     .. Scalar Arguments ..
       INTEGER            IA, JA, INFO, LRWORK, LWORK, M, N
@@ -187,6 +187,15 @@
 *     jpvt(j) = i
 *  then the jth column of P is the ith canonical unit vector.
 *
+*  References
+*  ==========
+*  
+*  For modifications introduced in Scalapack 2.1
+*  LAWN 295 
+*  New robust ScaLAPACK routine for computing the QR factorization with column pivoting
+*  Zvonimir Bujanovic, Zlatko Drmac
+*  http://www.netlib.org/lapack/lawnspdf/lawn295.pdf
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -205,7 +214,7 @@
      $                   J, JB, JJ, JJA, JJPVT, JN, KB, K, KK, KSTART,
      $                   KSTEP, LDA, LL, LRWMIN, LWMIN, MN, MP, MYCOL,
      $                   MYROW, NPCOL, NPROW, NQ, NQ0, PVT
-      REAL               TEMP, TEMP2
+      REAL               TEMP, TEMP2, TOL3Z
       COMPLEX            AJJ, ALPHA
 *     ..
 *     .. Local Arrays ..
@@ -221,6 +230,8 @@
 *     .. External Functions ..
       INTEGER            ICEIL, INDXG2P, NUMROC
       EXTERNAL           ICEIL, INDXG2P, NUMROC
+      REAL               SLAMCH
+      EXTERNAL           SLAMCH
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, CMPLX, CONJG, IFIX, MAX, MIN, MOD, SQRT
@@ -297,6 +308,7 @@
       IF( MYCOL.EQ.IACOL )
      $   NQ = NQ - ICOFF
       MN = MIN( M, N )
+      TOL3Z = SQRT( SLAMCH('Epsilon') )
 *
 *     Initialize the array of pivots
 *
@@ -501,14 +513,13 @@
          IF( MYCOL.EQ.ICURCOL ) THEN
             DO 90 LL = JJ, JJ + JN - J - 1
                IF( RWORK( LL ).NE.ZERO ) THEN
-                  TEMP = ONE-( ABS( WORK( LL ) ) / RWORK( LL ) )**2
-                  TEMP = MAX( TEMP, ZERO )
-                  TEMP2 = ONE + 0.05E+0*TEMP*
-     $                    ( RWORK( LL ) / RWORK( NQ+LL ) )**2
-                  IF( TEMP2.EQ.ONE ) THEN
+                  TEMP = ABS( WORK( LL ) ) / RWORK( LL )
+                  TEMP = MAX( ZERO, ( ONE+TEMP )*( ONE-TEMP ) )
+                  TEMP2 = TEMP * ( RWORK( LL ) / RWORK( NQ+LL ) )**2
+                  IF( TEMP2.LE.TOL3Z ) THEN
                      IF( IA+M-1.GT.I ) THEN
                         CALL PSCNRM2( IA+M-I-1, RWORK( LL ), A,
-     $                                I+1, J+LL-JJ, DESCA, 1 )
+     $                                I+1, J+LL-JJ+1, DESCA, 1 )
                         RWORK( NQ+LL ) = RWORK( LL )
                      ELSE
                         RWORK( LL ) = ZERO
@@ -529,11 +540,10 @@
             IF( MYCOL.EQ.ICURCOL ) THEN
                DO 100 LL = JJ, JJ+KB-1
                   IF( RWORK(LL).NE.ZERO ) THEN
-                     TEMP = ONE-( ABS( WORK( LL ) ) / RWORK( LL ) )**2
-                     TEMP = MAX( TEMP, ZERO )
-                     TEMP2 = ONE + 0.05E+0*TEMP*
-     $                       ( RWORK( LL ) / RWORK( NQ+LL ) )**2
-                     IF( TEMP2.EQ.ONE ) THEN
+                     TEMP = ABS( WORK( LL ) ) / RWORK( LL )
+                     TEMP = MAX( ZERO, ( ONE+TEMP )*( ONE-TEMP ) )
+                     TEMP2 = TEMP * ( RWORK( LL ) / RWORK( NQ+LL ) )**2
+                     IF( TEMP2.LE.TOL3Z ) THEN
                         IF( IA+M-1.GT.I ) THEN
                            CALL PSCNRM2( IA+M-I-1, RWORK( LL ), A,
      $                                   I+1, K+LL-JJ, DESCA, 1 )
