@@ -1,10 +1,9 @@
       SUBROUTINE PCHETTRD( UPLO, N, A, IA, JA, DESCA, D, E, TAU, WORK,
      $                     LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     October 15, 1999
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -443,7 +442,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, CGEBR2D, CGEBS2D, CGEMM, CGEMV,
-     $                   CGERV2D, CGESD2D, CGSUM2D, CHK1MAT, CLACPY,
+     $                   CGERV2D, CGESD2D, CGSUM2D, CHK1MAT, CLAMOV,
      $                   CSCAL, CTRMVT, PCHK1MAT, PSTREECOMB, PXERBLA,
      $                   SCOMBNRM2, SGEBR2D, SGEBS2D, SGSUM2D
 *     ..
@@ -1132,10 +1131,10 @@
                IF( INTERLEAVE ) THEN
                   LDZG = LDV / 2
                ELSE
-                  CALL CLACPY( 'A', LTNM1, ANB, WORK( INHT+LIJP1-1 ),
+                  CALL CLAMOV( 'A', LTNM1, ANB, WORK( INHT+LIJP1-1 ),
      $                         LDV, WORK( INVT+LIJP1-1+ANB*LDV ), LDV )
 *
-                  CALL CLACPY( 'A', LTNM1, ANB, WORK( INV+LTLIP1-1 ),
+                  CALL CLAMOV( 'A', LTNM1, ANB, WORK( INV+LTLIP1-1 ),
      $                         LDV, WORK( INH+LTLIP1-1+ANB*LDV ), LDV )
                   LDZG = LDV
                END IF
