@@ -1,5 +1,6 @@
       REAL               FUNCTION PCLANTR( NORM, UPLO, DIAG, M, N, A,
      $                                     IA, JA, DESCA, WORK )
+      IMPLICIT NONE
 *
 *  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
@@ -173,10 +174,10 @@
       INTEGER            IACOL, IAROW, ICTXT, II, IIA, ICOFF, IOFFA,
      $                   IROFF, J, JB, JJ, JJA, JN, KK, LDA, LL, MP,
      $                   MYCOL, MYROW, NP, NPCOL, NPROW, NQ
-      REAL               SCALE, SUM, VALUE
+      REAL               SUM, VALUE
 *     ..
 *     .. Local Arrays ..
-      REAL               RWORK( 2 )
+      REAL               SSQ( 2 ), COLSSQ( 2 )
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, CLASSQ, INFOG2L, PSTREECOMB,
@@ -215,6 +216,9 @@
       IF( MIN( M, N ).EQ.0 ) THEN
 *
          VALUE = ZERO
+*
+************************************************************************
+* max norm
 *
       ELSE IF( LSAME( NORM, 'M' ) ) THEN
 *
@@ -239,7 +243,7 @@
                IF( MYROW.EQ.IAROW ) THEN
                   IF( UDIAG ) THEN
                      DO 20 LL = JJ, JJ + JB -1
-                        DO 10 KK = IIA, MIN(II+LL-JJ+1,IIA+MP-1)
+                        DO 10 KK = IIA, MIN(II+LL-JJ-1,IIA+MP-1)
                            VALUE = MAX( VALUE, ABS( A( IOFFA+KK ) ) )
    10                   CONTINUE
                         IOFFA = IOFFA + LDA
@@ -277,7 +281,7 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 80 LL = JJ, JJ + JB -1
-                           DO 70 KK = IIA, MIN( II+LL-JJ+1, IIA+MP-1 )
+                           DO 70 KK = IIA, MIN( II+LL-JJ-1, IIA+MP-1 )
                               VALUE = MAX( VALUE, ABS( A( IOFFA+KK ) ) )
    70                      CONTINUE
                            IOFFA = IOFFA + LDA
@@ -396,6 +400,9 @@
 *
          CALL SGAMX2D( ICTXT, 'All', ' ', 1, 1, VALUE, 1, KK, LL, -1,
      $                 0, 0 )
+*
+************************************************************************
+* one norm
 *
       ELSE IF( LSAME( NORM, 'O' ) .OR. NORM.EQ.'1' ) THEN
 *
@@ -414,17 +421,22 @@
                IF( MYROW.EQ.IAROW ) THEN
                   IF( UDIAG ) THEN
                      DO 280 LL = JJ, JJ + JB -1
-                        SUM = ONE
-                        DO 270 KK = IIA, MIN( II+LL-JJ, IIA+MP-1 )
+                        SUM = ZERO
+                        DO 270 KK = IIA, MIN( II+LL-JJ-1, IIA+MP-1 )
                            SUM = SUM + ABS( A( IOFFA+KK ) )
   270                   CONTINUE
+*                       Unit diagonal entry
+                        KK = II+LL-JJ
+                        IF (KK <= IIA+MP-1) THEN
+                           SUM = SUM + ONE
+                        ENDIF
                         IOFFA = IOFFA + LDA
                         WORK( LL-JJA+1 ) = SUM
   280                CONTINUE
                   ELSE
                      DO 300 LL = JJ, JJ + JB -1
                         SUM = ZERO
-                        DO 290 KK = IIA, MIN( II+LL-JJ+1, IIA+MP-1 )
+                        DO 290 KK = IIA, MIN( II+LL-JJ, IIA+MP-1 )
                            SUM = SUM + ABS( A( IOFFA+KK ) )
   290                   CONTINUE
                         IOFFA = IOFFA + LDA
@@ -458,10 +470,15 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 340 LL = JJ, JJ + JB -1
-                           SUM = ONE
-                           DO 330 KK = IIA, MIN( II+LL-JJ+1, IIA+MP-1 )
+                           SUM = ZERO
+                           DO 330 KK = IIA, MIN( II+LL-JJ-1, IIA+MP-1 )
                               SUM = SUM + ABS( A( IOFFA+KK ) )
   330                      CONTINUE
+*                          Unit diagonal entry
+                           KK = II+LL-JJ
+                           IF (KK <= IIA+MP-1) THEN
+                              SUM = SUM + ONE
+                           ENDIF
                            IOFFA = IOFFA + LDA
                            WORK( LL-JJA+1 ) = SUM
   340                   CONTINUE
@@ -608,35 +625,20 @@
             CALL SGAMX2D( ICTXT, 'Rowwise', ' ', 1, 1, VALUE, 1, KK, LL,
      $                    -1, 0, 0 )
          END IF
+*
+************************************************************************
+* infinity norm
 *
       ELSE IF( LSAME( NORM, 'I' ) ) THEN
 *
          IF( LSAME( UPLO, 'U' ) ) THEN
-            IF( UDIAG ) THEN
-               DO 530 KK = IIA, IIA+MP-1
-                  WORK( KK ) = ONE
-  530          CONTINUE
-            ELSE
                DO 540 KK = IIA, IIA+MP-1
                   WORK( KK ) = ZERO
   540          CONTINUE
-            END IF
          ELSE
-            IF( UDIAG ) THEN
-               NP = NUMROC( N+IROFF, DESCA( MB_ ), MYROW, IAROW, NPROW )
-               IF( MYROW.EQ.IAROW )
-     $            NP = NP - IROFF
-               DO 550 KK = IIA, IIA+NP-1
-                  WORK( KK ) = ONE
-  550          CONTINUE
-               DO 560 KK = IIA+NP, IIA+MP-1
-                  WORK( KK ) = ZERO
-  560          CONTINUE
-            ELSE
                DO 570 KK = IIA, IIA+MP-1
                   WORK( KK ) = ZERO
   570          CONTINUE
-            END IF
          END IF
 *
          IF( LSAME( UPLO, 'U' ) ) THEN
@@ -652,15 +654,20 @@
                IF( MYROW.EQ.IAROW ) THEN
                   IF( UDIAG ) THEN
                      DO 590 LL = JJ, JJ + JB -1
-                        DO 580 KK = IIA, MIN( II+LL-JJ, IIA+MP-1 )
+                        DO 580 KK = IIA, MIN( II+LL-JJ-1, IIA+MP-1 )
                            WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) +
      $                                        ABS( A( IOFFA+KK ) )
   580                   CONTINUE
+*                       Unit diagonal entry
+                        KK = II+LL-JJ
+                        IF (KK <= IIA+MP-1) THEN
+                           WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) + ONE
+                        ENDIF
                         IOFFA = IOFFA + LDA
   590                CONTINUE
                   ELSE
                      DO 610 LL = JJ, JJ + JB -1
-                        DO 600 KK = IIA, MIN(II+LL-JJ+1,IIA+MP-1)
+                        DO 600 KK = IIA, MIN( II+LL-JJ, IIA+MP-1 )
                            WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) +
      $                                        ABS( A( IOFFA+KK ) )
   600                   CONTINUE
@@ -693,10 +700,15 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 650 LL = JJ, JJ + JB -1
-                           DO 640 KK = IIA, MIN( II+LL-JJ+1, IIA+MP-1 )
+                           DO 640 KK = IIA, MIN( II+LL-JJ-1, IIA+MP-1 )
                               WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) +
      $                                           ABS( A( IOFFA+KK ) )
   640                      CONTINUE
+*                          Unit diagonal entry
+                           KK = II+LL-JJ
+                           IF (KK <= IIA+MP-1) THEN
+                              WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) + ONE
+                           ENDIF
                            IOFFA = IOFFA + LDA
   650                   CONTINUE
                      ELSE
@@ -740,6 +752,9 @@
                IF( MYROW.EQ.IAROW ) THEN
                   IF( UDIAG ) THEN
                      DO 720 LL = JJ, JJ + JB -1
+*                       Unit diagonal entry
+                        KK = II+LL-JJ
+                        WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) + ONE
                         DO 710 KK = II+LL-JJ+1, IIA+MP-1
                            WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) +
      $                                        ABS( A( IOFFA+KK ) )
@@ -781,6 +796,9 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 780 LL = JJ, JJ + JB -1
+*                          Unit diagonal entry
+                           KK = II+LL-JJ
+                           WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) + ONE
                            DO 770 KK = II+LL-JJ+1, IIA+MP-1
                               WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) +
      $                                           ABS( A( IOFFA+KK ) )
@@ -834,57 +852,85 @@
             CALL SGAMX2D( ICTXT, 'Columnwise', ' ', 1, 1, VALUE, 1, KK,
      $                    LL, -1, 0, 0 )
          END IF
+*
+************************************************************************
+* Frobenius norm
+* SSQ(1) is scale
+* SSQ(2) is sum-of-squares
 *
       ELSE IF( LSAME( NORM, 'F' ) .OR. LSAME( NORM, 'E' ) ) THEN
 *
          IF( UDIAG ) THEN
-            SCALE = ONE
-            SUM = REAL( MIN( M, N ) ) / REAL( NPROW*NPCOL )
+            SSQ(1) = ONE
+            SSQ(2) = REAL( MIN( M, N ) ) / REAL( NPROW*NPCOL )
          ELSE
-            SCALE = ZERO
-            SUM = ONE
+            SSQ(1) = ZERO
+            SSQ(2) = ONE
          END IF
 *
          IF( LSAME( UPLO, 'U' ) ) THEN
 *
+*           ***********************
 *           Upper triangular matrix
 *
             II = IIA
             JJ = JJA
             JN = MIN( ICEIL( JA, DESCA( NB_ ) ) * DESCA( NB_ ), JA+N-1 )
             JB = JN-JA+1
+*
+*           First block column of sub-matrix.
 *
             IF( MYCOL.EQ.IACOL ) THEN
                IF( MYROW.EQ.IAROW ) THEN
+*                 This process has part of current block column,
+*                 including diagonal block.
                   IF( UDIAG ) THEN
                      DO 840 LL = JJ, JJ + JB -1
-                        CALL CLASSQ( MIN( II+LL-JJ, IIA+MP-1 )-IIA+1,
-     $                               A( IIA+IOFFA ), 1, SCALE, SUM )
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
+                        CALL CLASSQ( MIN( II+LL-JJ-1, IIA+MP-1 )-IIA+1,
+     $                               A( IIA+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL SCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   840                CONTINUE
                   ELSE
                      DO 850 LL = JJ, JJ + JB -1
-                        CALL CLASSQ( MIN( II+LL-JJ+1, IIA+MP-1 )-IIA+1,
-     $                               A( IIA+IOFFA ), 1, SCALE, SUM )
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
+                        CALL CLASSQ( MIN( II+LL-JJ, IIA+MP-1 )-IIA+1,
+     $                               A( IIA+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL SCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   850                CONTINUE
                   END IF
                ELSE
+*                 This rank has part of current block column,
+*                 but not diagonal block.
+*                 It seems this lassq will be length 0, since ii = iia.
                   DO 860 LL = JJ, JJ + JB -1
+                     COLSSQ(1) = ZERO
+                     COLSSQ(2) = ONE
                      CALL CLASSQ( MIN( II-1, IIA+MP-1 )-IIA+1,
-     $                            A( IIA+IOFFA ), 1, SCALE, SUM )
+     $                            A( IIA+IOFFA ), 1,
+     $                            COLSSQ(1), COLSSQ(2) )
+                     CALL SCOMBSSQ( SSQ, COLSSQ )
                      IOFFA = IOFFA + LDA
   860             CONTINUE
                END IF
                JJ = JJ + JB
             END IF
+*
+*           If this process has part of current block row, advance ii,
+*           then advance iarow, iacol to next diagonal block.
 *
             IF( MYROW.EQ.IAROW )
      $         II = II + JB
             IAROW = MOD( IAROW+1, NPROW )
             IACOL = MOD( IACOL+1, NPCOL )
 *
-*           Loop over remaining block of columns
+*           Loop over remaining block columns
 *
             DO 900 J = JN+1, JA+N-1, DESCA( NB_ )
                JB = MIN( JA+N-J, DESCA( NB_ ) )
@@ -893,23 +939,33 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 870 LL = JJ, JJ + JB -1
-                           CALL CLASSQ( MIN( II+LL-JJ+1, IIA+MP-1 )-
-     $                                  IIA+1, A( IIA+IOFFA ), 1, SCALE,
-     $                                  SUM )
+                           COLSSQ(1) = ZERO
+                           COLSSQ(2) = ONE
+                           CALL CLASSQ( MIN(II+LL-JJ-1, IIA+MP-1)-IIA+1,
+     $                                  A( IIA+IOFFA ), 1,
+     $                                  COLSSQ(1), COLSSQ(2) )
+                           CALL SCOMBSSQ( SSQ, COLSSQ )
                            IOFFA = IOFFA + LDA
   870                   CONTINUE
                      ELSE
                         DO 880 LL = JJ, JJ + JB -1
-                           CALL CLASSQ( MIN( II+LL-JJ, IIA+MP-1 )-
-     $                                  IIA+1, A( IIA+IOFFA ), 1, SCALE,
-     $                                  SUM )
+                           COLSSQ(1) = ZERO
+                           COLSSQ(2) = ONE
+                           CALL CLASSQ( MIN( II+LL-JJ, IIA+MP-1 )-IIA+1,
+     $                                  A( IIA+IOFFA ), 1,
+     $                                  COLSSQ(1), COLSSQ(2) )
+                           CALL SCOMBSSQ( SSQ, COLSSQ )
                            IOFFA = IOFFA + LDA
   880                   CONTINUE
                      END IF
                   ELSE
                      DO 890 LL = JJ, JJ + JB -1
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
                         CALL CLASSQ( MIN( II-1, IIA+MP-1 )-IIA+1,
-     $                               A( IIA+IOFFA ), 1, SCALE, SUM )
+     $                               A( IIA+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL SCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   890                CONTINUE
                   END IF
@@ -925,6 +981,7 @@
 *
          ELSE
 *
+*           ***********************
 *           Lower triangular matrix
 *
             II = IIA
@@ -936,23 +993,32 @@
                IF( MYROW.EQ.IAROW ) THEN
                   IF( UDIAG ) THEN
                      DO 910 LL = JJ, JJ + JB -1
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
                         CALL CLASSQ( IIA+MP-(II+LL-JJ+1),
-     $                               A( II+LL-JJ+IOFFA ), 1, SCALE,
-     $                               SUM )
+     $                               A( II+LL-JJ+1+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL SCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   910                CONTINUE
                   ELSE
                      DO 920 LL = JJ, JJ + JB -1
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
                         CALL CLASSQ( IIA+MP-(II+LL-JJ),
-     $                               A( II+LL-JJ+IOFFA ), 1, SCALE,
-     $                               SUM )
+     $                               A( II+LL-JJ+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL SCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   920                CONTINUE
                   END IF
                ELSE
                   DO 930 LL = JJ, JJ + JB -1
-                     CALL CLASSQ( IIA+MP-II, A( II+IOFFA ), 1, SCALE,
-     $                            SUM )
+                     COLSSQ(1) = ZERO
+                     COLSSQ(2) = ONE
+                     CALL CLASSQ( IIA+MP-II, A( II+IOFFA ), 1,
+     $                            COLSSQ(1), COLSSQ(2) )
+                     CALL SCOMBSSQ( SSQ, COLSSQ )
                      IOFFA = IOFFA + LDA
   930             CONTINUE
                END IF
@@ -973,23 +1039,32 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 940 LL = JJ, JJ + JB -1
+                           COLSSQ(1) = ZERO
+                           COLSSQ(2) = ONE
                            CALL CLASSQ( IIA+MP-(II+LL-JJ+1),
-     $                                  A( II+LL-JJ+IOFFA ), 1, SCALE,
-     $                                  SUM )
+     $                                  A( II+LL-JJ+1+IOFFA ), 1,
+     $                                  COLSSQ(1), COLSSQ(2) )
+                           CALL SCOMBSSQ( SSQ, COLSSQ )
                            IOFFA = IOFFA + LDA
   940                   CONTINUE
                      ELSE
                         DO 950 LL = JJ, JJ + JB -1
+                           COLSSQ(1) = ZERO
+                           COLSSQ(2) = ONE
                            CALL CLASSQ( IIA+MP-(II+LL-JJ),
-     $                                  A( II+LL-JJ+IOFFA ), 1, SCALE,
-     $                                  SUM )
+     $                                  A( II+LL-JJ+IOFFA ), 1,
+     $                                  COLSSQ(1), COLSSQ(2) )
+                           CALL SCOMBSSQ( SSQ, COLSSQ )
                            IOFFA = IOFFA + LDA
   950                   CONTINUE
                      END IF
                   ELSE
                      DO 960 LL = JJ, JJ + JB -1
-                        CALL CLASSQ( IIA+MP-II, A( II+IOFFA ), 1, SCALE,
-     $                               SUM )
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
+                        CALL CLASSQ( IIA+MP-II, A( II+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL SCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   960                CONTINUE
                   END IF
@@ -1005,12 +1080,11 @@
 *
          END IF
 *
+*        ***********************
 *        Perform the global scaled sum
 *
-         RWORK( 1 ) = SCALE
-         RWORK( 2 ) = SUM
-         CALL PSTREECOMB( ICTXT, 'All', 2, RWORK, 0, 0, SCOMBSSQ )
-         VALUE = RWORK( 1 ) * SQRT( RWORK( 2 ) )
+         CALL PSTREECOMB( ICTXT, 'All', 2, SSQ, 0, 0, SCOMBSSQ )
+         VALUE = SSQ( 1 ) * SQRT( SSQ( 2 ) )
 *
       END IF
 *
