@@ -1,5 +1,6 @@
       DOUBLE PRECISION   FUNCTION PDLANTR( NORM, UPLO, DIAG, M, N, A,
      $                                     IA, JA, DESCA, WORK )
+      IMPLICIT NONE
 *
 *  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
@@ -172,10 +173,10 @@
       INTEGER            IACOL, IAROW, ICTXT, II, IIA, ICOFF, IOFFA,
      $                   IROFF, J, JB, JJ, JJA, JN, KK, LDA, LL, MP,
      $                   MYCOL, MYROW, NP, NPCOL, NPROW, NQ
-      DOUBLE PRECISION   SCALE, SUM, VALUE
+      DOUBLE PRECISION   SUM, VALUE
 *     ..
 *     .. Local Arrays ..
-      DOUBLE PRECISION   RWORK( 2 )
+      DOUBLE PRECISION   SSQ( 2 ), COLSSQ( 2 )
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, DCOMBSSQ, DGEBR2D,
@@ -214,6 +215,9 @@
       IF( MIN( M, N ).EQ.0 ) THEN
 *
          VALUE = ZERO
+*
+************************************************************************
+* max norm
 *
       ELSE IF( LSAME( NORM, 'M' ) ) THEN
 *
@@ -238,7 +242,7 @@
                IF( MYROW.EQ.IAROW ) THEN
                   IF( UDIAG ) THEN
                      DO 20 LL = JJ, JJ + JB -1
-                        DO 10 KK = IIA, MIN(II+LL-JJ+1,IIA+MP-1)
+                        DO 10 KK = IIA, MIN(II+LL-JJ-1,IIA+MP-1)
                            VALUE = MAX( VALUE, ABS( A( IOFFA+KK ) ) )
    10                   CONTINUE
                         IOFFA = IOFFA + LDA
@@ -276,7 +280,7 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 80 LL = JJ, JJ + JB -1
-                           DO 70 KK = IIA, MIN( II+LL-JJ+1, IIA+MP-1 )
+                           DO 70 KK = IIA, MIN( II+LL-JJ-1, IIA+MP-1 )
                               VALUE = MAX( VALUE, ABS( A( IOFFA+KK ) ) )
    70                      CONTINUE
                            IOFFA = IOFFA + LDA
@@ -395,6 +399,9 @@
 *
          CALL DGAMX2D( ICTXT, 'All', ' ', 1, 1, VALUE, 1, KK, LL, -1,
      $                 0, 0 )
+*
+************************************************************************
+* one norm
 *
       ELSE IF( LSAME( NORM, 'O' ) .OR. NORM.EQ.'1' ) THEN
 *
@@ -413,17 +420,22 @@
                IF( MYROW.EQ.IAROW ) THEN
                   IF( UDIAG ) THEN
                      DO 280 LL = JJ, JJ + JB -1
-                        SUM = ONE
-                        DO 270 KK = IIA, MIN( II+LL-JJ, IIA+MP-1 )
+                        SUM = ZERO
+                        DO 270 KK = IIA, MIN( II+LL-JJ-1, IIA+MP-1 )
                            SUM = SUM + ABS( A( IOFFA+KK ) )
   270                   CONTINUE
+*                       Unit diagonal entry
+                        KK = II+LL-JJ
+                        IF (KK <= IIA+MP-1) THEN
+                           SUM = SUM + ONE
+                        ENDIF
                         IOFFA = IOFFA + LDA
                         WORK( LL-JJA+1 ) = SUM
   280                CONTINUE
                   ELSE
                      DO 300 LL = JJ, JJ + JB -1
                         SUM = ZERO
-                        DO 290 KK = IIA, MIN( II+LL-JJ+1, IIA+MP-1 )
+                        DO 290 KK = IIA, MIN( II+LL-JJ, IIA+MP-1 )
                            SUM = SUM + ABS( A( IOFFA+KK ) )
   290                   CONTINUE
                         IOFFA = IOFFA + LDA
@@ -457,10 +469,15 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 340 LL = JJ, JJ + JB -1
-                           SUM = ONE
-                           DO 330 KK = IIA, MIN( II+LL-JJ+1, IIA+MP-1 )
+                           SUM = ZERO
+                           DO 330 KK = IIA, MIN( II+LL-JJ-1, IIA+MP-1 )
                               SUM = SUM + ABS( A( IOFFA+KK ) )
   330                      CONTINUE
+*                          Unit diagonal entry
+                           KK = II+LL-JJ
+                           IF (KK <= IIA+MP-1) THEN
+                              SUM = SUM + ONE
+                           ENDIF
                            IOFFA = IOFFA + LDA
                            WORK( LL-JJA+1 ) = SUM
   340                   CONTINUE
@@ -607,35 +624,20 @@
             CALL DGAMX2D( ICTXT, 'Rowwise', ' ', 1, 1, VALUE, 1, KK, LL,
      $                    -1, 0, 0 )
          END IF
+*
+************************************************************************
+* infinity norm
 *
       ELSE IF( LSAME( NORM, 'I' ) ) THEN
 *
          IF( LSAME( UPLO, 'U' ) ) THEN
-            IF( UDIAG ) THEN
-               DO 530 KK = IIA, IIA+MP-1
-                  WORK( KK ) = ONE
-  530          CONTINUE
-            ELSE
                DO 540 KK = IIA, IIA+MP-1
                   WORK( KK ) = ZERO
   540          CONTINUE
-            END IF
          ELSE
-            IF( UDIAG ) THEN
-               NP = NUMROC( N+IROFF, DESCA( MB_ ), MYROW, IAROW, NPROW )
-               IF( MYROW.EQ.IAROW )
-     $            NP = NP - IROFF
-               DO 550 KK = IIA, IIA+NP-1
-                  WORK( KK ) = ONE
-  550          CONTINUE
-               DO 560 KK = IIA+NP, IIA+MP-1
-                  WORK( KK ) = ZERO
-  560          CONTINUE
-            ELSE
                DO 570 KK = IIA, IIA+MP-1
                   WORK( KK ) = ZERO
   570          CONTINUE
-            END IF
          END IF
 *
          IF( LSAME( UPLO, 'U' ) ) THEN
@@ -651,15 +653,20 @@
                IF( MYROW.EQ.IAROW ) THEN
                   IF( UDIAG ) THEN
                      DO 590 LL = JJ, JJ + JB -1
-                        DO 580 KK = IIA, MIN( II+LL-JJ, IIA+MP-1 )
+                        DO 580 KK = IIA, MIN( II+LL-JJ-1, IIA+MP-1 )
                            WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) +
      $                                        ABS( A( IOFFA+KK ) )
   580                   CONTINUE
+*                       Unit diagonal entry
+                        KK = II+LL-JJ
+                        IF (KK <= IIA+MP-1) THEN
+                           WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) + ONE
+                        ENDIF
                         IOFFA = IOFFA + LDA
   590                CONTINUE
                   ELSE
                      DO 610 LL = JJ, JJ + JB -1
-                        DO 600 KK = IIA, MIN(II+LL-JJ+1,IIA+MP-1)
+                        DO 600 KK = IIA, MIN( II+LL-JJ, IIA+MP-1 )
                            WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) +
      $                                        ABS( A( IOFFA+KK ) )
   600                   CONTINUE
@@ -692,10 +699,15 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 650 LL = JJ, JJ + JB -1
-                           DO 640 KK = IIA, MIN( II+LL-JJ+1, IIA+MP-1 )
+                           DO 640 KK = IIA, MIN( II+LL-JJ-1, IIA+MP-1 )
                               WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) +
      $                                           ABS( A( IOFFA+KK ) )
   640                      CONTINUE
+*                          Unit diagonal entry
+                           KK = II+LL-JJ
+                           IF (KK <= IIA+MP-1) THEN
+                              WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) + ONE
+                           ENDIF
                            IOFFA = IOFFA + LDA
   650                   CONTINUE
                      ELSE
@@ -739,6 +751,9 @@
                IF( MYROW.EQ.IAROW ) THEN
                   IF( UDIAG ) THEN
                      DO 720 LL = JJ, JJ + JB -1
+*                       Unit diagonal entry
+                        KK = II+LL-JJ
+                        WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) + ONE
                         DO 710 KK = II+LL-JJ+1, IIA+MP-1
                            WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) +
      $                                        ABS( A( IOFFA+KK ) )
@@ -780,6 +795,9 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 780 LL = JJ, JJ + JB -1
+*                          Unit diagonal entry
+                           KK = II+LL-JJ
+                           WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) + ONE
                            DO 770 KK = II+LL-JJ+1, IIA+MP-1
                               WORK( KK-IIA+1 ) = WORK( KK-IIA+1 ) +
      $                                           ABS( A( IOFFA+KK ) )
@@ -833,57 +851,85 @@
             CALL DGAMX2D( ICTXT, 'Columnwise', ' ', 1, 1, VALUE, 1, KK,
      $                    LL, -1, 0, 0 )
          END IF
+*
+************************************************************************
+* Frobenius norm
+* SSQ(1) is scale
+* SSQ(2) is sum-of-squares
 *
       ELSE IF( LSAME( NORM, 'F' ) .OR. LSAME( NORM, 'E' ) ) THEN
 *
          IF( UDIAG ) THEN
-            SCALE = ONE
-            SUM = DBLE( MIN( M, N ) ) / DBLE( NPROW*NPCOL )
+            SSQ(1) = ONE
+            SSQ(2) = DBLE( MIN( M, N ) ) / DBLE( NPROW*NPCOL )
          ELSE
-            SCALE = ZERO
-            SUM = ONE
+            SSQ(1) = ZERO
+            SSQ(2) = ONE
          END IF
 *
          IF( LSAME( UPLO, 'U' ) ) THEN
 *
+*           ***********************
 *           Upper triangular matrix
 *
             II = IIA
             JJ = JJA
             JN = MIN( ICEIL( JA, DESCA( NB_ ) ) * DESCA( NB_ ), JA+N-1 )
             JB = JN-JA+1
+*
+*           First block column of sub-matrix.
 *
             IF( MYCOL.EQ.IACOL ) THEN
                IF( MYROW.EQ.IAROW ) THEN
+*                 This process has part of current block column,
+*                 including diagonal block.
                   IF( UDIAG ) THEN
                      DO 840 LL = JJ, JJ + JB -1
-                        CALL DLASSQ( MIN( II+LL-JJ, IIA+MP-1 )-IIA+1,
-     $                               A( IIA+IOFFA ), 1, SCALE, SUM )
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
+                        CALL DLASSQ( MIN( II+LL-JJ-1, IIA+MP-1 )-IIA+1,
+     $                               A( IIA+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL DCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   840                CONTINUE
                   ELSE
                      DO 850 LL = JJ, JJ + JB -1
-                        CALL DLASSQ( MIN( II+LL-JJ+1, IIA+MP-1 )-IIA+1,
-     $                               A( IIA+IOFFA ), 1, SCALE, SUM )
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
+                        CALL DLASSQ( MIN( II+LL-JJ, IIA+MP-1 )-IIA+1,
+     $                               A( IIA+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL DCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   850                CONTINUE
                   END IF
                ELSE
+*                 This rank has part of current block column,
+*                 but not diagonal block.
+*                 It seems this lassq will be length 0, since ii = iia.
                   DO 860 LL = JJ, JJ + JB -1
+                     COLSSQ(1) = ZERO
+                     COLSSQ(2) = ONE
                      CALL DLASSQ( MIN( II-1, IIA+MP-1 )-IIA+1,
-     $                            A( IIA+IOFFA ), 1, SCALE, SUM )
+     $                            A( IIA+IOFFA ), 1,
+     $                            COLSSQ(1), COLSSQ(2) )
+                     CALL DCOMBSSQ( SSQ, COLSSQ )
                      IOFFA = IOFFA + LDA
   860             CONTINUE
                END IF
                JJ = JJ + JB
             END IF
+*
+*           If this process has part of current block row, advance ii,
+*           then advance iarow, iacol to next diagonal block.
 *
             IF( MYROW.EQ.IAROW )
      $         II = II + JB
             IAROW = MOD( IAROW+1, NPROW )
             IACOL = MOD( IACOL+1, NPCOL )
 *
-*           Loop over remaining block of columns
+*           Loop over remaining block columns
 *
             DO 900 J = JN+1, JA+N-1, DESCA( NB_ )
                JB = MIN( JA+N-J, DESCA( NB_ ) )
@@ -892,23 +938,33 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 870 LL = JJ, JJ + JB -1
-                           CALL DLASSQ( MIN( II+LL-JJ+1, IIA+MP-1 )-
-     $                                  IIA+1, A( IIA+IOFFA ), 1, SCALE,
-     $                                  SUM )
+                           COLSSQ(1) = ZERO
+                           COLSSQ(2) = ONE
+                           CALL DLASSQ( MIN(II+LL-JJ-1, IIA+MP-1)-IIA+1,
+     $                                  A( IIA+IOFFA ), 1,
+     $                                  COLSSQ(1), COLSSQ(2) )
+                           CALL DCOMBSSQ( SSQ, COLSSQ )
                            IOFFA = IOFFA + LDA
   870                   CONTINUE
                      ELSE
                         DO 880 LL = JJ, JJ + JB -1
-                           CALL DLASSQ( MIN( II+LL-JJ, IIA+MP-1 )-
-     $                                  IIA+1, A( IIA+IOFFA ), 1, SCALE,
-     $                                  SUM )
+                           COLSSQ(1) = ZERO
+                           COLSSQ(2) = ONE
+                           CALL DLASSQ( MIN( II+LL-JJ, IIA+MP-1 )-IIA+1,
+     $                                  A( IIA+IOFFA ), 1,
+     $                                  COLSSQ(1), COLSSQ(2) )
+                           CALL DCOMBSSQ( SSQ, COLSSQ )
                            IOFFA = IOFFA + LDA
   880                   CONTINUE
                      END IF
                   ELSE
                      DO 890 LL = JJ, JJ + JB -1
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
                         CALL DLASSQ( MIN( II-1, IIA+MP-1 )-IIA+1,
-     $                               A( IIA+IOFFA ), 1, SCALE, SUM )
+     $                               A( IIA+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL DCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   890                CONTINUE
                   END IF
@@ -924,6 +980,7 @@
 *
          ELSE
 *
+*           ***********************
 *           Lower triangular matrix
 *
             II = IIA
@@ -935,23 +992,32 @@
                IF( MYROW.EQ.IAROW ) THEN
                   IF( UDIAG ) THEN
                      DO 910 LL = JJ, JJ + JB -1
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
                         CALL DLASSQ( IIA+MP-(II+LL-JJ+1),
-     $                               A( II+LL-JJ+IOFFA ), 1, SCALE,
-     $                               SUM )
+     $                               A( II+LL-JJ+1+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL DCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   910                CONTINUE
                   ELSE
                      DO 920 LL = JJ, JJ + JB -1
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
                         CALL DLASSQ( IIA+MP-(II+LL-JJ),
-     $                               A( II+LL-JJ+IOFFA ), 1, SCALE,
-     $                               SUM )
+     $                               A( II+LL-JJ+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL DCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   920                CONTINUE
                   END IF
                ELSE
                   DO 930 LL = JJ, JJ + JB -1
-                     CALL DLASSQ( IIA+MP-II, A( II+IOFFA ), 1, SCALE,
-     $                            SUM )
+                     COLSSQ(1) = ZERO
+                     COLSSQ(2) = ONE
+                     CALL DLASSQ( IIA+MP-II, A( II+IOFFA ), 1,
+     $                            COLSSQ(1), COLSSQ(2) )
+                     CALL DCOMBSSQ( SSQ, COLSSQ )
                      IOFFA = IOFFA + LDA
   930             CONTINUE
                END IF
@@ -972,23 +1038,32 @@
                   IF( MYROW.EQ.IAROW ) THEN
                      IF( UDIAG ) THEN
                         DO 940 LL = JJ, JJ + JB -1
+                           COLSSQ(1) = ZERO
+                           COLSSQ(2) = ONE
                            CALL DLASSQ( IIA+MP-(II+LL-JJ+1),
-     $                                  A( II+LL-JJ+IOFFA ), 1, SCALE,
-     $                                  SUM )
+     $                                  A( II+LL-JJ+1+IOFFA ), 1,
+     $                                  COLSSQ(1), COLSSQ(2) )
+                           CALL DCOMBSSQ( SSQ, COLSSQ )
                            IOFFA = IOFFA + LDA
   940                   CONTINUE
                      ELSE
                         DO 950 LL = JJ, JJ + JB -1
+                           COLSSQ(1) = ZERO
+                           COLSSQ(2) = ONE
                            CALL DLASSQ( IIA+MP-(II+LL-JJ),
-     $                                  A( II+LL-JJ+IOFFA ), 1, SCALE,
-     $                                  SUM )
+     $                                  A( II+LL-JJ+IOFFA ), 1,
+     $                                  COLSSQ(1), COLSSQ(2) )
+                           CALL DCOMBSSQ( SSQ, COLSSQ )
                            IOFFA = IOFFA + LDA
   950                   CONTINUE
                      END IF
                   ELSE
                      DO 960 LL = JJ, JJ + JB -1
-                        CALL DLASSQ( IIA+MP-II, A( II+IOFFA ), 1, SCALE,
-     $                               SUM )
+                        COLSSQ(1) = ZERO
+                        COLSSQ(2) = ONE
+                        CALL DLASSQ( IIA+MP-II, A( II+IOFFA ), 1,
+     $                               COLSSQ(1), COLSSQ(2) )
+                        CALL DCOMBSSQ( SSQ, COLSSQ )
                         IOFFA = IOFFA + LDA
   960                CONTINUE
                   END IF
@@ -1004,12 +1079,11 @@
 *
          END IF
 *
+*        ***********************
 *        Perform the global scaled sum
 *
-         RWORK( 1 ) = SCALE
-         RWORK( 2 ) = SUM
-         CALL PDTREECOMB( ICTXT, 'All', 2, RWORK, 0, 0, DCOMBSSQ )
-         VALUE = RWORK( 1 ) * SQRT( RWORK( 2 ) )
+         CALL PDTREECOMB( ICTXT, 'All', 2, SSQ, 0, 0, DCOMBSSQ )
+         VALUE = SSQ( 1 ) * SQRT( SSQ( 2 ) )
 *
       END IF
 *
