@@ -1,10 +1,10 @@
       SUBROUTINE PDORMQR( SIDE, TRANS, M, N, K, A, IA, JA, DESCA, TAU,
      $                    C, IC, JC, DESCC, WORK, LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.5) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     May 25, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE, TRANS
@@ -132,7 +132,7 @@
 *  DESCA   (global and local input) INTEGER array of dimension DLEN_.
 *          The array descriptor for the distributed matrix A.
 *
-*  TAU     (local input) DOUBLE PRECISION, array, dimension LOCc(JA+K-1).
+*  TAU     (local input) DOUBLE PRECISION array, dimension LOCc(JA+K-1).
 *          This array contains the scalar factors TAU(j) of the
 *          elementary reflectors H(j) as returned by PDGEQRF.
 *          TAU is tied to the distributed matrix A.
@@ -235,7 +235,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, CHK1MAT, PCHK2MAT, PDLARFB,
-     $                   PDLARFT, PDORM2R, PTOPGET, PTOPSET, PXERBLA
+     $                   PDLARFT, PDORM2R, PB_TOPGET, PB_TOPSET, PXERBLA
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -366,8 +366,8 @@
       IF( M.EQ.0 .OR. N.EQ.0 .OR. K.EQ.0 )
      $   RETURN
 *
-      CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
-      CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+      CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+      CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
 *
       IF( ( LEFT .AND. .NOT.NOTRAN ) .OR.
      $    ( .NOT.LEFT .AND. NOTRAN ) ) THEN
@@ -386,11 +386,11 @@
          NI  = N
          JCC = JC
          IF( NOTRAN ) THEN
-            CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', 'D-ring' )
+            CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', 'D-ring' )
          ELSE
-            CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', 'I-ring' )
+            CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', 'I-ring' )
          END IF
-         CALL PTOPSET( ICTXT, 'Broadcast', 'Columnwise', ' ' )
+         CALL PB_TOPSET( ICTXT, 'Broadcast', 'Columnwise', ' ' )
       ELSE
          MI  = M
          ICC = IC
@@ -438,8 +438,8 @@
      $   CALL PDORM2R( SIDE, TRANS, M, N, J2-JA, A, IA, JA, DESCA, TAU,
      $                 C, IC, JC, DESCC, WORK, LWORK, IINFO )
 *
-      CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
-      CALL PTOPSET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+      CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+      CALL PB_TOPSET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
 *
       WORK( 1 ) = DBLE( LWMIN )
 *
