@@ -1,10 +1,9 @@
       SUBROUTINE PSDBTRF( N, BWL, BWU, A, JA, DESCA, AF, LAF, WORK,
      $                    LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     March 12, 2002 
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       INTEGER            BWL, BWU, INFO, JA, LAF, LWORK, N
@@ -371,7 +370,7 @@
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, SAXPY, SDBTRF,
      $                   DESC_CONVERT, SGEMM, SGEMV, SGERV2D, SGESD2D,
-     $                   SLACPY, SLATCPY, STBTRS, STRMM, STRRV2D,
+     $                   SLAMOV, SLATCPY, STBTRS, STRMM, STRRV2D,
      $                   STRSD2D, GLOBCHK, IGAMX2D, IGEBR2D, IGEBS2D,
      $                   PXERBLA, RESHAPE
 *     ..
@@ -723,7 +722,7 @@
          CALL SLATCPY( 'U', BWL, BWL, A( ( OFST+( BWL+BWU+1 )+
      $                 ( ODD_SIZE-BWL )*LLDA ) ), LLDA-1,
      $                 AF( ODD_SIZE*BWU+2*MBW2+1+MAX_BW-BWL ), MAX_BW )
-         CALL SLACPY( 'L', BWU, BWU, A( ( OFST+1+ODD_SIZE*LLDA ) ),
+         CALL SLAMOV( 'L', BWU, BWU, A( ( OFST+1+ODD_SIZE*LLDA ) ),
      $                LLDA-1, AF( WORK_U+ODD_SIZE*BWL+2*MBW2+1+MAX_BW-
      $                BWU ), MAX_BW )
 *
@@ -750,7 +749,7 @@
 *
 *         Move the resulting block back to its location in main storage.
 *
-         CALL SLACPY( 'L', BWU, BWU, AF( WORK_U+ODD_SIZE*BWL+2*MBW2+1+
+         CALL SLAMOV( 'L', BWU, BWU, AF( WORK_U+ODD_SIZE*BWL+2*MBW2+1+
      $                MAX_BW-BWU ), MAX_BW, A( ( OFST+1+ODD_SIZE*
      $                LLDA ) ), LLDA-1 )
 *
@@ -816,7 +815,7 @@
 *
 *         Copy D block into AF storage for solve.
 *
-            CALL SLACPY( 'L', UP_PREV_TRI_SIZE_N, UP_PREV_TRI_SIZE_M,
+            CALL SLAMOV( 'L', UP_PREV_TRI_SIZE_N, UP_PREV_TRI_SIZE_M,
      $                   A( OFST+1 ), LLDA-1, AF( 1 ), BWU )
 *
             DO 80 I1 = 1, ODD_SIZE
@@ -865,7 +864,7 @@
 *             Since we have GU_i stored,
 *             transpose HU_i to HU_i^T.
 *
-               CALL SLACPY( 'N', BWL, BWL,
+               CALL SLAMOV( 'N', BWL, BWL,
      $                      AF( WORK_U+( ODD_SIZE-BWL )*BWL+1 ), BWL,
      $                      AF( ( ODD_SIZE )*BWU+1+( MAX_BW-BWL ) ),
      $                      MAX_BW )
@@ -881,7 +880,7 @@
 *             Since we have GL_i^T stored,
 *             transpose HL_i^T to HL_i.
 *
-               CALL SLACPY( 'N', BWU, BWU, AF( ( ODD_SIZE-BWU )*BWU+1 ),
+               CALL SLAMOV( 'N', BWU, BWU, AF( ( ODD_SIZE-BWU )*BWU+1 ),
      $                      BWU, AF( WORK_U+( ODD_SIZE )*BWL+1+MAX_BW-
      $                      BWU ), MAX_BW )
 *
@@ -946,7 +945,7 @@
 *       Copy last diagonal block into AF storage for subsequent
 *         operations.
 *
-      CALL SLACPY( 'N', MAX_BW, MAX_BW, A( OFST+ODD_SIZE*LLDA+BWU+1 ),
+      CALL SLAMOV( 'N', MAX_BW, MAX_BW, A( OFST+ODD_SIZE*LLDA+BWU+1 ),
      $             LLDA-1, AF( ODD_SIZE*BWU+MBW2+1 ), MAX_BW )
 *
 *       Receive cont. to diagonal block that is stored on this proc.
@@ -1030,10 +1029,10 @@
 *           Move block into place that it will be expected to be for
 *             calcs.
 *
-         CALL SLACPY( 'N', MAX_BW, MAX_BW, AF( ODD_SIZE*BWU+1 ), MAX_BW,
+         CALL SLAMOV( 'N', MAX_BW, MAX_BW, AF( ODD_SIZE*BWU+1 ), MAX_BW,
      $                AF( WORK_U+ODD_SIZE*BWL+2*MBW2+1 ), MAX_BW )
 *
-         CALL SLACPY( 'N', MAX_BW, MAX_BW, AF( WORK_U+ODD_SIZE*BWL+1 ),
+         CALL SLAMOV( 'N', MAX_BW, MAX_BW, AF( WORK_U+ODD_SIZE*BWL+1 ),
      $                MAX_BW, AF( ODD_SIZE*BWU+2*MBW2+1 ), MAX_BW )
 *
       ELSE
