@@ -1,10 +1,10 @@
       SUBROUTINE PSLARF( SIDE, M, N, V, IV, JV, DESCV, INCV, TAU,
      $                   C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     May 25, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE
@@ -244,7 +244,7 @@
       REAL               TAULOC
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDINFO, INFOG2L, PTOPGET, PBSTRNV,
+      EXTERNAL           BLACS_GRIDINFO, INFOG2L, PB_TOPGET, PBSTRNV,
      $                   SCOPY, SGEBR2D, SGEBS2D, SGEMV,
      $                   SGER, SGERV2D, SGESD2D, SGSUM2D,
      $                   SLASET
@@ -484,8 +484,10 @@
 *                 w := sub( C )' * v
 *
                   IF( MP.GT.0 ) THEN
-                     CALL SGEMV( 'Transpose', MP, NQ, ONE, C( IOFFC ),
-     $                           LDC, WORK, 1, ZERO, WORK( IPW ), 1 )
+                     IF( IOFFC.GT.0 )
+     $                  CALL SGEMV( 'Transpose', MP, NQ, ONE,
+     $                              C( IOFFC ), LDC, WORK, 1, ZERO,
+     $                              WORK( IPW ), 1 )
                   ELSE
                      CALL SLASET( 'All', NQ, 1, ZERO, ZERO,
      $                            WORK( IPW ), MAX( 1, NQ ) )
@@ -496,15 +498,16 @@
 *
 *                 sub( C ) := sub( C ) - v * w'
 *
-                  CALL SGER( MP, NQ, -TAULOC, WORK, 1, WORK( IPW ), 1,
-     $                       C( IOFFC ), LDC )
+                  IF( IOFFC.GT.0 )
+     $               CALL SGER( MP, NQ, -TAULOC, WORK, 1, WORK( IPW ),
+     $                          1, C( IOFFC ), LDC )
                END IF
 *
             ELSE
 *
 *              Broadcast column vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
                IF( MYCOL.EQ.IVCOL ) THEN
 *
                   IPW = MP+1
@@ -528,8 +531,10 @@
 *                 w := sub( C )' * v
 *
                   IF( MP.GT.0 ) THEN
-                     CALL SGEMV( 'Transpose', MP, NQ, ONE, C( IOFFC ),
-     $                           LDC, WORK, 1, ZERO, WORK( IPW ), 1 )
+                     IF( IOFFC.GT.0 )
+     $                  CALL SGEMV( 'Transpose', MP, NQ, ONE,
+     $                              C( IOFFC ), LDC, WORK, 1, ZERO,
+     $                              WORK( IPW ), 1 )
                   ELSE
                      CALL SLASET( 'All', NQ, 1, ZERO, ZERO,
      $                            WORK( IPW ), MAX( 1, NQ ) )
@@ -540,8 +545,9 @@
 *
 *                 sub( C ) := sub( C ) - v * w'
 *
-                  CALL SGER( MP, NQ, -TAULOC, WORK, 1, WORK( IPW ), 1,
-     $                       C( IOFFC ), LDC )
+                  IF( IOFFC.GT.0 )
+     $               CALL SGER( MP, NQ, -TAULOC, WORK, 1, WORK( IPW ),
+     $                          1, C( IOFFC ), LDC )
                END IF
 *
             END IF
@@ -589,8 +595,9 @@
 *
 *                       sub( C ) := sub( C ) - w * v'
 *
-                        CALL SGER( MP, NQ, -TAULOC, WORK, 1, V( IOFFV ),
-     $                             LDV, C( IOFFC ), LDC )
+                        IF( IOFFV.GT.0 .AND. IOFFC.GT.0 )
+     $                     CALL SGER( MP, NQ, -TAULOC, WORK, 1,
+     $                                V( IOFFV ), LDV, C( IOFFC ), LDC )
                      END IF
 *
                   END IF
@@ -701,11 +708,13 @@
 *
 *              Broadcast row vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise',
+     $                         COLBTOP )
                IF( MYROW.EQ.IVROW ) THEN
 *
                   IPW = NQ+1
-                  CALL SCOPY( NQ, V( IOFFV ), LDV, WORK, 1 )
+                  IF( IOFFV.GT.0 )
+     $               CALL SCOPY( NQ, V( IOFFV ), LDV, WORK, 1 )
                   WORK(IPW) = TAU( IIV )
                   CALL SGEBS2D( ICTXT, 'Columnwise', COLBTOP, IPW, 1,
      $                          WORK, IPW )
@@ -738,8 +747,9 @@
 *
 *                 sub( C ) := sub( C ) - w * v'
 *
-                  CALL SGER( MP, NQ, -TAULOC, WORK( IPW ), 1, WORK, 1,
-     $                       C( IOFFC ), LDC )
+                  IF( IOFFC.GT.0 )
+     $               CALL SGER( MP, NQ, -TAULOC, WORK( IPW ), 1, WORK,
+     $                          1, C( IOFFC ), LDC )
                END IF
 *
             ELSE
