@@ -1,10 +1,10 @@
       SUBROUTINE PSLARZ( SIDE, M, N, L, V, IV, JV, DESCV, INCV, TAU, C,
      $                   IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     May 25, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE
@@ -253,7 +253,7 @@
       REAL               TAULOC
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDINFO, INFOG2L, PTOPGET, PBSTRNV,
+      EXTERNAL           BLACS_GRIDINFO, INFOG2L, PB_TOPGET, PBSTRNV,
      $                   SAXPY, SCOPY, SGEBR2D, SGEBS2D,
      $                   SGEMV, SGER, SGERV2D, SGESD2D,
      $                   SGSUM2D, SLASET
@@ -571,7 +571,7 @@
 *
 *              Broadcast column vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
                IF( MYCOL.EQ.IVCOL ) THEN
 *
                   IPW = MPV+1
@@ -673,8 +673,10 @@
 *
 *                       sub( C ) := sub( C ) - w * v'
 *
-                        CALL SGER( MPC2, NQV, -TAULOC, WORK, 1,
-     $                             V( IOFFV ), LDV, C( IOFFC2 ), LDC )
+                        IF( MPC2.GT.0 .AND. NQV.GT.0 )
+     $                     CALL SGER( MPC2, NQV, -TAULOC, WORK, 1,
+     $                                V( IOFFV ), LDV, C( IOFFC2 ),
+     $                                LDC )
                      END IF
 *
                   END IF
@@ -797,7 +799,8 @@
 *
 *              Broadcast row vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise',
+     $                         COLBTOP )
                IF( MYROW.EQ.IVROW ) THEN
 *
                   IPW = NQV+1
