@@ -1,10 +1,9 @@
       SUBROUTINE PSSYTTRD( UPLO, N, A, IA, JA, DESCA, D, E, TAU, WORK,
      $                     LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     October 15, 1999
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -441,7 +440,7 @@
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, CHK1MAT, PCHK1MAT, PSTREECOMB,
      $                   PXERBLA, SCOMBNRM2, SGEBR2D, SGEBS2D, SGEMM,
-     $                   SGEMV, SGERV2D, SGESD2D, SGSUM2D, SLACPY,
+     $                   SGEMV, SGERV2D, SGESD2D, SGSUM2D, SLAMOV,
      $                   SSCAL, STRMVT
 *     ..
 *     .. External Functions ..
@@ -1127,10 +1126,10 @@
                IF( INTERLEAVE ) THEN
                   LDZG = LDV / 2
                ELSE
-                  CALL SLACPY( 'A', LTNM1, ANB, WORK( INHT+LIJP1-1 ),
+                  CALL SLAMOV( 'A', LTNM1, ANB, WORK( INHT+LIJP1-1 ),
      $                         LDV, WORK( INVT+LIJP1-1+ANB*LDV ), LDV )
 *
-                  CALL SLACPY( 'A', LTNM1, ANB, WORK( INV+LTLIP1-1 ),
+                  CALL SLAMOV( 'A', LTNM1, ANB, WORK( INV+LTLIP1-1 ),
      $                         LDV, WORK( INH+LTLIP1-1+ANB*LDV ), LDV )
                   LDZG = LDV
                END IF
