@@ -1,5 +1,6 @@
       DOUBLE PRECISION FUNCTION PZLANSY( NORM, UPLO, N, A, IA, JA,
      $                                   DESCA, WORK )
+      IMPLICIT NONE
 *
 *  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
@@ -174,10 +175,10 @@
      $                   ICURROW, II, IIA, IN, IROFF, ICSR, ICSR0,
      $                   IOFFA, IRSC, IRSC0, IRSR, IRSR0, JJ, JJA, K,
      $                   LDA, LL, MYCOL, MYROW, NP, NPCOL, NPROW, NQ
-      DOUBLE PRECISION   SCALE, SUM, VALUE
+      DOUBLE PRECISION   SUM, VALUE
 *     ..
 *     .. Local Arrays ..
-      DOUBLE PRECISION   RWORK( 2 )
+      DOUBLE PRECISION   SSQ( 2 ), COLSSQ( 2 )
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, DAXPY, DCOMBSSQ,
@@ -264,6 +265,9 @@
       IF( N.EQ.0 ) THEN
 *
          VALUE = ZERO
+*
+************************************************************************
+* max norm
 *
       ELSE IF( LSAME( NORM, 'M' ) ) THEN
 *
@@ -457,6 +461,9 @@
 *
          CALL DGAMX2D( ICTXT, 'All', ' ', 1, 1, VALUE, 1, I, K, -1,
      $                 IAROW, IACOL )
+*
+************************************************************************
+* one or inf norm
 *
       ELSE IF( LSAME( NORM, 'I' ) .OR. LSAME( NORM, 'O' ) .OR.
      $         NORM.EQ.'1' ) THEN
@@ -705,13 +712,18 @@
             CALL DGAMX2D( ICTXT, 'Rowwise', ' ', 1, 1, VALUE, 1, I, K,
      $                    -1, IAROW, IACOL )
          END IF
+*
+************************************************************************
+* Frobenius norm
+* SSQ(1) is scale
+* SSQ(2) is sum-of-squares
 *
       ELSE IF( LSAME( NORM, 'F' ) .OR. LSAME( NORM, 'E' ) ) THEN
 *
 *        Find normF( sub( A ) ).
 *
-         SCALE = ZERO
-         SUM = ONE
+         SSQ(1) = ZERO
+         SSQ(2) = ONE
 *
 *        Add off-diagonal entries, first
 *
@@ -723,10 +735,15 @@
 *
             IF( MYCOL.EQ.IACOL ) THEN
                DO 370 K = (JJ-1)*LDA, (JJ+IB-2)*LDA, LDA
-                  CALL ZLASSQ( II-IIA, A( IIA+K ), 1, SCALE, SUM )
+                  COLSSQ(1) = ZERO
+                  COLSSQ(2) = ONE
+                  CALL ZLASSQ( II-IIA, A( IIA+K ), 1,
+     $                         COLSSQ(1), COLSSQ(2) )
                   IF( MYROW.EQ.IAROW )
      $               II = II + 1
-                  CALL ZLASSQ( II-IIA, A( IIA+K ), 1, SCALE, SUM )
+                  CALL ZLASSQ( II-IIA, A( IIA+K ), 1,
+     $                         COLSSQ(1), COLSSQ(2) )
+                  CALL DCOMBSSQ( SSQ, COLSSQ )
   370          CONTINUE
 *
                JJ = JJ + IB
@@ -744,10 +761,15 @@
 *
                IF( MYCOL.EQ.ICURCOL ) THEN
                   DO 380 K = (JJ-1)*LDA, (JJ+IB-2)*LDA, LDA
-                     CALL ZLASSQ( II-IIA, A( IIA+K ), 1, SCALE, SUM )
+                     COLSSQ(1) = ZERO
+                     COLSSQ(2) = ONE
+                     CALL ZLASSQ( II-IIA, A( IIA+K ), 1,
+     $                            COLSSQ(1), COLSSQ(2) )
                      IF( MYROW.EQ.ICURROW )
      $                  II = II + 1
-                     CALL ZLASSQ( II-IIA, A( IIA+K ), 1, SCALE, SUM )
+                     CALL ZLASSQ( II-IIA, A (IIA+K ), 1,
+     $                            COLSSQ(1), COLSSQ(2) )
+                     CALL DCOMBSSQ( SSQ, COLSSQ )
   380             CONTINUE
 *
                   JJ = JJ + IB
@@ -768,10 +790,15 @@
 *
             IF( MYCOL.EQ.IACOL ) THEN
                DO 400 K = (JJ-1)*LDA, (JJ+IB-2)*LDA, LDA
-                  CALL ZLASSQ( IIA+NP-II, A( II+K ), 1, SCALE, SUM )
+                  COLSSQ(1) = ZERO
+                  COLSSQ(2) = ONE
+                  CALL ZLASSQ( IIA+NP-II, A( II+K ), 1,
+     $                         COLSSQ(1), COLSSQ(2) )
                   IF( MYROW.EQ.IAROW )
      $               II = II + 1
-                  CALL ZLASSQ( IIA+NP-II, A( II+K ), 1, SCALE, SUM )
+                  CALL ZLASSQ( IIA+NP-II, A( II+K ), 1,
+     $                         COLSSQ(1), COLSSQ(2) )
+                  CALL DCOMBSSQ( SSQ, COLSSQ )
   400          CONTINUE
 *
                JJ = JJ + IB
@@ -789,10 +816,15 @@
 *
                IF( MYCOL.EQ.ICURCOL ) THEN
                   DO 410 K = (JJ-1)*LDA, (JJ+IB-2)*LDA, LDA
-                     CALL ZLASSQ( IIA+NP-II, A( II+K ), 1, SCALE, SUM )
+                     COLSSQ(1) = ZERO
+                     COLSSQ(2) = ONE
+                     CALL ZLASSQ( IIA+NP-II, A( II+K ), 1,
+     $                            COLSSQ(1), COLSSQ(2) )
                      IF( MYROW.EQ.ICURROW )
      $                  II = II + 1
-                     CALL ZLASSQ( IIA+NP-II, A( II+K ), 1, SCALE, SUM )
+                     CALL ZLASSQ( IIA+NP-II, A( II+K ), 1,
+     $                            COLSSQ(1), COLSSQ(2) )
+                     CALL DCOMBSSQ( SSQ, COLSSQ )
   410             CONTINUE
 *
                   JJ = JJ + IB
@@ -809,12 +841,9 @@
 *
 *        Perform the global scaled sum
 *
-         RWORK( 1 ) = SCALE
-         RWORK( 2 ) = SUM
-*
-         CALL PDTREECOMB( ICTXT, 'All', 2, RWORK, IAROW, IACOL,
+         CALL PDTREECOMB( ICTXT, 'All', 2, SSQ, IAROW, IACOL,
      $                    DCOMBSSQ )
-         VALUE = RWORK( 1 ) * SQRT( RWORK( 2 ) )
+         VALUE = SSQ( 1 ) * SQRT( SSQ( 2 ) )
 *
       END IF
 *
