@@ -1,10 +1,10 @@
       SUBROUTINE PZLARF( SIDE, M, N, V, IV, JV, DESCV, INCV, TAU,
      $                   C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     May 25, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE
@@ -245,7 +245,7 @@
       COMPLEX*16         TAULOC
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDINFO, INFOG2L, PTOPGET, PBZTRNV,
+      EXTERNAL           BLACS_GRIDINFO, INFOG2L, PB_TOPGET, PBZTRNV,
      $                   ZCOPY, ZGEBR2D, ZGEBS2D, ZGEMV,
      $                   ZGERC, ZGERV2D, ZGESD2D, ZGSUM2D,
      $                   ZLASET
@@ -485,9 +485,10 @@
 *                 w := sub( C )' * v
 *
                   IF( MP.GT.0 ) THEN
-                     CALL ZGEMV( 'Conjugate transpose', MP, NQ, ONE,
-     $                           C( IOFFC ), LDC, WORK, 1, ZERO,
-     $                           WORK( IPW ), 1 )
+                     IF( IOFFC.GT.0 )
+     $                  CALL ZGEMV( 'Conjugate transpose', MP, NQ, ONE,
+     $                              C( IOFFC ), LDC, WORK, 1, ZERO,
+     $                              WORK( IPW ), 1 )
                   ELSE
                      CALL ZLASET( 'All', NQ, 1, ZERO, ZERO,
      $                            WORK( IPW ), MAX( 1, NQ ) )
@@ -498,15 +499,16 @@
 *
 *                 sub( C ) := sub( C ) - v * w'
 *
-                  CALL ZGERC( MP, NQ, -TAULOC, WORK, 1, WORK( IPW ), 1,
-     $                        C( IOFFC ), LDC )
+                  IF( IOFFC.GT.0 )
+     $               CALL ZGERC( MP, NQ, -TAULOC, WORK, 1, WORK( IPW ),
+     $                           1, C( IOFFC ), LDC )
                END IF
 *
             ELSE
 *
 *              Broadcast column vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
                IF( MYCOL.EQ.IVCOL ) THEN
 *
                   IPW = MP+1
@@ -530,9 +532,10 @@
 *                 w := sub( C )' * v
 *
                   IF( MP.GT.0 ) THEN
-                     CALL ZGEMV( 'Conjugate transpose', MP, NQ, ONE,
-     $                           C( IOFFC ), LDC, WORK, 1, ZERO,
-     $                           WORK( IPW ), 1 )
+                     IF( IOFFC.GT.0 )
+     $                  CALL ZGEMV( 'Conjugate transpose', MP, NQ, ONE,
+     $                              C( IOFFC ), LDC, WORK, 1, ZERO,
+     $                              WORK( IPW ), 1 )
                   ELSE
                      CALL ZLASET( 'All', NQ, 1, ZERO, ZERO,
      $                            WORK( IPW ), MAX( 1, NQ ) )
@@ -543,8 +546,9 @@
 *
 *                 sub( C ) := sub( C ) - v * w'
 *
-                  CALL ZGERC( MP, NQ, -TAULOC, WORK, 1, WORK( IPW ), 1,
-     $                        C( IOFFC ), LDC )
+                  IF( IOFFC.GT.0 )
+     $               CALL ZGERC( MP, NQ, -TAULOC, WORK, 1, WORK( IPW ),
+     $                           1, C( IOFFC ), LDC )
                END IF
 *
             END IF
@@ -592,8 +596,10 @@
 *
 *                       sub( C ) := sub( C ) - w * v'
 *
-                        CALL ZGERC( MP, NQ, -TAULOC, WORK, 1,
-     $                              V( IOFFV ), LDV, C( IOFFC ), LDC )
+                        IF( IOFFV.GT.0 .AND. IOFFC.GT.0 )
+     $                     CALL ZGERC( MP, NQ, -TAULOC, WORK, 1,
+     $                                 V( IOFFV ), LDV, C( IOFFC ),
+     $                                 LDC )
                      END IF
 *
                   END IF
@@ -704,11 +710,13 @@
 *
 *              Broadcast row vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise',
+     $                       COLBTOP )
                IF( MYROW.EQ.IVROW ) THEN
 *
                   IPW = NQ+1
-                  CALL ZCOPY( NQ, V( IOFFV ), LDV, WORK, 1 )
+                  IF( IOFFV.GT.0 )
+     $               CALL ZCOPY( NQ, V( IOFFV ), LDV, WORK, 1 )
                   WORK(IPW) = TAU( IIV )
                   CALL ZGEBS2D( ICTXT, 'Columnwise', COLBTOP, IPW, 1,
      $                          WORK, IPW )
@@ -741,8 +749,9 @@
 *
 *                 sub( C ) := sub( C ) - w * v'
 *
-                  CALL ZGERC( MP, NQ, -TAULOC, WORK( IPW ), 1, WORK, 1,
-     $                        C( IOFFC ), LDC )
+                  IF( IOFFC.GT.0 )
+     $               CALL ZGERC( MP, NQ, -TAULOC, WORK( IPW ), 1, WORK,
+     $                           1, C( IOFFC ), LDC )
                END IF
 *
             ELSE
