@@ -1,10 +1,10 @@
       SUBROUTINE PZLARZ( SIDE, M, N, L, V, IV, JV, DESCV, INCV, TAU, C,
      $                   IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     May 25, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE
@@ -254,7 +254,7 @@
       COMPLEX*16         TAULOC
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDINFO, INFOG2L, PTOPGET, PBZTRNV,
+      EXTERNAL           BLACS_GRIDINFO, INFOG2L, PB_TOPGET, PBZTRNV,
      $                   ZAXPY, ZCOPY, ZGEBR2D, ZGEBS2D,
      $                   ZGEMV, ZGERC, ZGERV2D, ZGESD2D,
      $                   ZGSUM2D, ZLASET
@@ -572,7 +572,7 @@
 *
 *              Broadcast column vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
                IF( MYCOL.EQ.IVCOL ) THEN
 *
                   IPW = MPV+1
@@ -674,8 +674,10 @@
 *
 *                       sub( C ) := sub( C ) - w * v'
 *
-                        CALL ZGERC( MPC2, NQV, -TAULOC, WORK, 1,
-     $                              V( IOFFV ), LDV, C( IOFFC2 ), LDC )
+                        IF( MPC2.GT.0 .AND. NQV.GT.0 )
+     $                     CALL ZGERC( MPC2, NQV, -TAULOC, WORK, 1,
+     $                                 V( IOFFV ), LDV, C( IOFFC2 ),
+     $                                 LDC )
                      END IF
 *
                   END IF
@@ -798,7 +800,8 @@
 *
 *              Broadcast row vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise',
+     $                         COLBTOP )
                IF( MYROW.EQ.IVROW ) THEN
 *
                   IPW = NQV+1
