@@ -1,10 +1,9 @@
       SUBROUTINE PZLARZB( SIDE, TRANS, DIRECT, STOREV, M, N, K, L, V,
      $                    IV, JV, DESCV, T, C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     March 14, 2000
+*  -- ScaLAPACK auxiliary routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIRECT, SIDE, STOREV, TRANS
@@ -244,7 +243,7 @@
       EXTERNAL           BLACS_ABORT, BLACS_GRIDINFO, INFOG2L,
      $                   PBZMATADD, PB_TOPGET, PXERBLA, PBZTRAN,
      $                   ZGEBR2D, ZGEBS2D, ZGEMM,
-     $                   ZGSUM2D, ZLACGV, ZLACPY, ZLASET,
+     $                   ZGSUM2D, ZLACGV, ZLAMOV, ZLASET,
      $                   ZTRBR2D, ZTRBS2D, ZTRMM
 *     ..
 *     .. Intrinsic Functions ..
@@ -381,10 +380,10 @@
 *
          IF( MYROW.EQ.IVROW ) THEN
             IF( MYCOL.EQ.IVCOL ) THEN
-               CALL ZLACPY( 'All', K, MQV, V( IOFFV ), LDV,
+               CALL ZLAMOV( 'All', K, MQV, V( IOFFV ), LDV,
      $                      WORK( IPW+ICOFFV*LW ), LW )
             ELSE
-               CALL ZLACPY( 'All', K, MQV, V( IOFFV ), LDV,
+               CALL ZLAMOV( 'All', K, MQV, V( IOFFV ), LDV,
      $                      WORK( IPW ), LW )
             END IF
          END IF
@@ -517,7 +516,7 @@
             IF( MYCOL.EQ.IVCOL )
      $         CALL ZTRBS2D( ICTXT, 'Columnwise', COLBTOP, 'Lower',
      $                       'Non unit', K, K, T, MBV )
-            CALL ZLACPY( 'All', K, NQC2, V( IOFFV ), LDV, WORK( IPV ),
+            CALL ZLAMOV( 'All', K, NQC2, V( IOFFV ), LDV, WORK( IPV ),
      $                   LV )
          ELSE
             CALL ZGEBR2D( ICTXT, 'Columnwise', COLBTOP, K, NQC2,
