@@ -1,7 +1,7 @@
       PROGRAM PCPTDRIVER
 *
 *
-*  -- ScaLAPACK routine (version 1.6 ALPHA) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
 *     November 15, 1997
@@ -66,7 +66,7 @@
 *
 *  Code Developer: Andrew J. Cleary, University of Tennessee.
 *    Current address: Lawrence Livermore National Labs.
-*  This version released: May, 1997.
+*  This version released: August, 2001.
 *
 *  =====================================================================
 *
@@ -490,8 +490,8 @@
                   MEM( IPA+INT_TEMP+H-1 ) = MEM( IPA+INT_TEMP+2*H-2 )
      $               +MEM( IPA+INT_TEMP+2*H-1 )*( 0.0E+0, 1.0E+0 )
    10   CONTINUE
-               IF( 2*(NUMROC(N,NB,MYCOL,0,NPCOL)/2).
-     $               NE.NUMROC(N,NB,MYCOL,0,NPCOL) ) THEN
+               IF( 2*(NUMROC(N,NB,MYCOL,0,NPCOL)/2).NE.
+     $               NUMROC(N,NB,MYCOL,0,NPCOL) ) THEN
                   H=NUMROC(N,NB,MYCOL,0,NPCOL)/2+1
                   MEM( IPA+INT_TEMP+H-1 ) = MEM( IPA+INT_TEMP+2*H-2 )
                ENDIF
