@@ -1,9 +1,9 @@
       PROGRAM PZLSDRIVER
 *
-*  -- ScaLAPACK routine (version 1.5) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     August 14, 2001
 *
 *  Purpose
 *  =======
@@ -67,13 +67,13 @@
      $                     CTXT_ = 2, M_ = 3, N_ = 4, MB_ = 5, NB_ = 6,
      $                     RSRC_ = 7, CSRC_ = 8, LLD_ = 9 )
       INTEGER            DBLESZ, MEMSIZ, NTESTS, TOTMEM, ZPLXSZ
-      DOUBLE PRECISION   RZERO
+      DOUBLE PRECISION   RZERO, RONE
       COMPLEX*16         ONE, PADVAL, ZERO
       PARAMETER          ( DBLESZ = 8, ZPLXSZ = 16, TOTMEM = 2000000,
      $                     MEMSIZ = TOTMEM / ZPLXSZ, NTESTS = 20,
      $                     PADVAL = ( -9923.0D+0, -9923.0D+0 ) )
       PARAMETER          ( ONE = ( 1.0D+0, 0.0D+0 ), RZERO = 0.0D+0,
-     $                     ZERO = ( 0.0D+0, 0.0D+0 ) )
+     $                     RONE = 1.0D+0, ZERO = ( 0.0D+0, 0.0D+0 ) )
 *     ..
 *     .. Local Scalars ..
       LOGICAL            CHECK, TPSD
@@ -467,7 +467,7 @@
                               CALL PDZNRM2( NCOLS, BNORM, MEM( IPW ),
      $                                      1, JJ, DESCW, 1 )
                               IF( BNORM.GT.RZERO )
-     $                           CALL PZDSCAL( NCOLS, ONE / BNORM,
+     $                           CALL PZDSCAL( NCOLS, RONE / BNORM,
      $                                         MEM( IPW ), 1, JJ, DESCW,
      $                                         1 )
    10                      CONTINUE
@@ -986,8 +986,8 @@
                               END IF
                               NOPS = ADDFAC*ADDS + MULFAC*MULTS
 *
-*                             Calculate total megaflops, for WALL and CPU
-*                             time, and print output
+*                             Calculate total megaflops, for WALL and
+*                             CPU time, and print output
 *
 *                             Print WALL time if machine supports it
 *
